@@ -26,7 +26,7 @@
 # ~/.profile (or ~/.bashrc, or whatever you prefer) so that pinto runs
 # naturally in your everyday shell environment.
 #
-# All the depndencies for pinto come from a curated repository hosted at
+# All the depndencies for pinto come from a curated repository on hosted
 # http://stratopan.com.  That repository contains specific versions of all 
 # the modules that pinto needs.  So those may not be the latest versions,
 # but they are versions that I know will work (and that's the whole point
@@ -39,34 +39,10 @@
 # which may or may not be 100% compatible with pinto (usually they are, but 
 # you never know).
 #
-# CONFIGURATION
-#
-# The following environment variables can be used to control the installation:
-#
-# PINTO_HOME
-#
-#   Sets the directory where pinto will be installed. 
-#   Defaults to $HOME/opt/local/pinto
-#
-# PINTO_REPO_URL
-#
-#   Sets the URL of the repository that provides pinto's dependencies
-#   Defaults to https://www.stratopan.com/thaljef/OpenSource/pinto-release
-#
-# PINTO_INSTALLER_AGENT
-#
-#   Sets the name of the tool that will be used to fetch cpanm.  If set, 
-#   it must be either 'curl' or 'wget'.  If not set, the installer will
-#   fallback to either 'curl' or 'wget' (in that order) depending on what
-#   you already have installed.
-#
-# PERL_CPANM_OPT
-#
-#   Sets the default options for cpanm, which is used to install pinto.  This
-#   can be useful if you need to specify a certain agent such as lwp, curl,
-#   or wget.  See https://metacpan.org/module/cpanm for more details.
-#
-# Copyright 2013 Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+# If you have any feedback or suggestions, please contact jeff@stratopan.com
+# I'm especially keen to get suggestion on how to rig up this kind of 
+# installation process for other platforms & environments (e.g. Windows, 
+# csh, zsh, etc.)
 #
 ##############################################################################
 
@@ -75,41 +51,24 @@ set -ue
 #-----------------------------------------------------------------------------
 # You can set these variables beforehand to override defaults
 
-PINTO_REPO_URL=${PINTO_REPO_URL:="https://www.stratopan.com/thaljef/OpenSource/pinto-release"}
+PINTO_REPO_URL=${PINTO_REPO_URL:="http://stratopan.com/Stratopan/Pinto/Production"}
 PINTO_HOME=${PINTO_HOME:="$HOME/opt/local/pinto"}
 
-#-----------------------------------------------------------------------------
-# Decide which agent to use.  Set PINTO_INSTALLER_AGENT to override
-
-if  [ -z ${PINTO_INSTALLER_AGENT:-} ]; then
-
-    if type curl > /dev/null 2>&1; then
-        PINTO_INSTALLER_AGENT='curl'
-    elif type wget > /dev/null 2>&1; then 
-        PINTO_INSTALLER_AGENT='wget'
-    else
-        echo "Must have curl or wget to install pinto"
-        exit 1
-    fi
-fi
-
 #-----------------------------------------------------------------------------
 # Bootstrap cpanm
 
-PINTO_CPANM_URL=${PINTO_CPANM_URL:="https://raw.githubusercontent.com/thaljef/Pinto/master/etc/cpanm"}
+CPANM_URL="http://cpanmin.us"
 PINTO_SBIN="$PINTO_HOME/sbin"
 PINTO_CPANM_EXE="$PINTO_SBIN/cpanm"
 
 mkdir -p "$PINTO_SBIN"
 
-if   [ $PINTO_INSTALLER_AGENT = 'curl' ]; then
-	curl --silent --show-error --location $PINTO_CPANM_URL > "$PINTO_CPANM_EXE"
-elif [ $PINTO_INSTALLER_AGENT = 'wget' ]; then 
-	wget --no-verbose --output-document - $PINTO_CPANM_URL > "$PINTO_CPANM_EXE"
+if   type curl > /dev/null 2>&1; then
+	curl --silent --show-error --location $CPANM_URL > "$PINTO_CPANM_EXE"
+elif type wget > /dev/null 2>&1; then 
+	wget --no-verbose --output-document - $CPANM_URL > "$PINTO_CPANM_EXE"
 else
-	echo "Invalid PINTO_INSTALLER_AGENT ($PINTO_INSTALLER_AGENT)."
-        echo "If set, PINTO_INSTALLER_AGENT must be 'curl' or 'wget'".
-        exit 1;
+	echo "Must have curl or wget to install pinto"
 fi
 
 chmod 755 "$PINTO_CPANM_EXE"
@@ -119,11 +78,8 @@ chmod 755 "$PINTO_CPANM_EXE"
 
 echo "Installing pinto into $PINTO_HOME"
 
-# Workaround for removal of "." from @INC in perl 5.26.0
-export PERL_USE_UNSAFE_INC=1
-
 "$PINTO_CPANM_EXE" --notest --quiet --mirror $PINTO_REPO_URL --mirror-only  \
-      --local-lib-contained "$PINTO_HOME" --man-pages Pinto
+      --local-lib-contained "$PINTO_HOME" --man-pages Pinto App::Pinto
 
 # TODO: send the build log and `perl -V` back for analysis
 if [ $? -ne 0 ] ; then echo "Installation failed."; exit 1; fi
@@ -161,18 +117,15 @@ END_CONFIG
 
 cat <<END_MSG
 pinto has been installed at $PINTO_HOME.  
-To activate it, give this command:
+To activate, give this command:
 
   source $PINTO_HOME/etc/bashrc
 
 To make pinto part of your everyday environment, add that 
-last command to your ~/.profile or ~/.bashrc file as well.
+command to your ~/.profile or ~/.bashrc file as well.  
 
-We want your feedback!  Help us make Pinto better by
-writing a review of Pinto at http://cpanratings.perl.org.
-
-Got questions about Pinto?  We have the answers!  Contact
-us at team@stratopan.com or on the #pinto channel on IRC.
+Thank you for installing pinto. I hope you find it useful.
+Send feedback to jeff@stratopan.com
 END_MSG
 
 #-----------------------------------------------------------------------------
