@@ -11,7 +11,7 @@ use Pinto::SpecFactory;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.079_01'; # VERSION
+our $VERSION = '0.079_04'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -33,12 +33,32 @@ has do_pull => (
     default => 0,
 );
 
+
+has mirror_url => (
+    is      => 'ro',
+    isa     => Str,
+    builder => '_build_mirror_url',
+    lazy    => 1,
+);
+
 #------------------------------------------------------------------------------
 
 with qw( Pinto::Role::Committable Pinto::Role::Puller Pinto::Role::Installer);
 
 #------------------------------------------------------------------------------
 
+sub _build_mirror_url {
+    my ($self) = @_;
+
+    my $stack      = $self->stack;
+    my $stack_dir  = defined $stack ? "/stacks/$stack" : '';
+    my $mirror_url = 'file://' . $self->repo->root->absolute . $stack_dir;
+
+    return $mirror_url;
+}
+
+#------------------------------------------------------------------------------
+
 sub execute {
     my ($self) = @_;
 
@@ -78,7 +98,7 @@ Pinto::Action::Install - Install packages from the repository
 
 =head1 VERSION
 
-version 0.079_01
+version 0.079_04
 
 =head1 CONTRIBUTORS
 
