@@ -11,7 +11,7 @@ use base 'Exporter';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.079_01'; # VERSION
+our $VERSION = '0.079_04'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -21,10 +21,6 @@ Readonly our @EXPORT_OK => qw(
     $PINTO_SERVER_DEFAULT_HOST
     $PINTO_SERVER_DEFAULT_ROOT
 
-    $PINTO_SERVER_TEST_PORT
-    $PINTO_SERVER_TEST_HOST
-    $PINTO_SERVER_TEST_ROOT
-
     $PINTO_SERVER_STATUS_OK
     $PINTO_SERVER_DIAG_PREFIX
 
@@ -64,15 +60,6 @@ Readonly our $PINTO_SERVER_DEFAULT_ROOT  =>
 
 #------------------------------------------------------------------------------
 
-Readonly our $PINTO_SERVER_TEST_HOST => 'localhost';
-
-Readonly our $PINTO_SERVER_TEST_PORT => 3321;
-
-Readonly our $PINTO_SERVER_TEST_ROOT =>
-  "http://$PINTO_SERVER_TEST_HOST:$PINTO_SERVER_TEST_PORT";
-
-#------------------------------------------------------------------------------
-
 Readonly our $PINTO_SERVER_DIAG_PREFIX => '## ';
 
 Readonly our $PINTO_SERVER_STATUS_OK => "${PINTO_SERVER_DIAG_PREFIX}Status: ok";
@@ -120,7 +107,7 @@ Pinto::Constants - Constants used across the Pinto utilities
 
 =head1 VERSION
 
-version 0.079_01
+version 0.079_04
 
 =head1 CONTRIBUTORS
 
